==> huhk-1.9.1.tar.gz: huhk-1.9.1/service/app_a/asserts/content/asserts_content_essayweb.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_essayweb import SqlsContentEssayweb


class AssertsContentEssayweb(SqlsContentEssayweb):
    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_add(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_add(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId", "publishChannel", "publishTime", "content", "author", "publishType", "essPicUrl", "title", "status"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_searchbykey(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_searchbykey(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["key"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_delete_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_delete_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_getbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_getbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId", "subjectId"])
        assert True, "数据比较不一致"

==> huhk-1.9.6.tar.gz: huhk-1.9.6/service/app_a/asserts/content/asserts_content_essayweb.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_essayweb import SqlsContentEssayweb


class AssertsContentEssayweb(SqlsContentEssayweb):
    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_add(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_add(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["publishChannel", "author", "title", "essayId", "publishTime", "essPicUrl", "status", "content", "publishType"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_searchbykey(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_searchbykey(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["key"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_delete_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_delete_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["essayId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_essayweb_getbyid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_essayweb_getbyid(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["subjectId", "essayId"])
        assert True, "数据比较不一致"
